@@ -1,7 +1,6 @@
 # qemu backend
 
 from UpgradeTestBackendSSH import UpgradeTestBackendSSH
-from DistUpgrade.DistUpgradeConfigParser import DistUpgradeConfig
 from DistUpgrade.sourceslist import SourcesList
 
 import ConfigParser
@@ -12,11 +11,7 @@ import os.path
 import shutil
 import glob
 import time
-import signal
-import signal
-import crypt
 import tempfile
-import copy
 import atexit
 import apt_pkg
 
@@ -71,20 +66,23 @@ class UpgradeTestBackendQemu(UpgradeTestBackendSSH):
         # setup mount dir/imagefile location
         self.baseimage = self.config.get("KVM","BaseImage")
         if not os.path.exists(self.baseimage):
-            ret = subprocess.call(["ubuntu-vm-builder","kvm", self.fromDist,
+            print "Missing '%s' base image, need to build it now" % self.baseimage
+            ret = subprocess.call(["sudo",
+                                   "ubuntu-vm-builder","kvm", self.fromDist,
                                    "--kernel-flavour", "generic",
                                    "--ssh-key", "%s.pub" % self.ssh_key ,
                                    "--components", "main,restricted",
                                    "--rootsize", "80000",
+                                   "--addpkg", "openssh-server",
                                    "--arch", "i386"])
             # move the disk in place
-            shutil.move("ubuntu-kvm/disk0.qcow2",self.baseimage)
+            shutil.move(glob.glob("ubuntu-kvm/*.qcow2")[0],self.baseimage)
             if ret != 0:
                 raise NoImageFoundException
         # check if we want virtio here and default to yes
         try:
             self.virtio = self.config.getboolean("KVM","Virtio")
-        except ConfigParser.NoOptionError,e:
+        except ConfigParser.NoOptionError:
             self.virtio = True
         if self.virtio:
             self.qemu_options.extend(["-net","nic,model=virtio"])
@@ -128,12 +126,12 @@ class UpgradeTestBackendQemu(UpgradeTestBackendSSH):
         """
         # generate ls -R output of test-image (
         self.start()
-        ret = self._runInImage(["find", "/bin", "/boot", "/etc/", "/home",
-                                "/initrd", "/lib", "/root", "/sbin/",
-                                "/srv", "/usr", "/var"],
-                               stdout=open(self.resultdir+"/upgrade_install.files","w"))
-        ret = self._runInImage(["dpkg","--get-selections"],
-                               stdout=open(self.resultdir+"/upgrade_install.pkgs","w"))
+        self._runInImage(["find", "/bin", "/boot", "/etc/", "/home",
+                          "/initrd", "/lib", "/root", "/sbin/",
+                          "/srv", "/usr", "/var"],
+                         stdout=open(self.resultdir+"/upgrade_install.files","w"))
+        self._runInImage(["dpkg","--get-selections"],
+                         stdout=open(self.resultdir+"/upgrade_install.pkgs","w"))
         self._runInImage(["tar","cvf","/tmp/etc-upgrade.tar","/etc"])
         self._copyFromImage("/tmp/etc-upgrade.tar", self.resultdir)
         self.stop()
@@ -156,12 +154,12 @@ class UpgradeTestBackendQemu(UpgradeTestBackendSSH):
         print "bootstrap finshsed"
         self.start()
         print "generating file diff list"
-        ret = self._runInImage(["find", "/bin", "/boot", "/etc/", "/home",
-                                "/initrd", "/lib", "/root", "/sbin/",
-                                "/srv", "/usr", "/var"],
-                               stdout=open(self.resultdir+"/fresh_install","w"))
-        ret = self._runInImage(["dpkg","--get-selections"],
-                               stdout=open(self.resultdir+"/fresh_install.pkgs","w"))
+        self._runInImage(["find", "/bin", "/boot", "/etc/", "/home",
+                          "/initrd", "/lib", "/root", "/sbin/",
+                          "/srv", "/usr", "/var"],
+                         stdout=open(self.resultdir+"/fresh_install","w"))
+        self._runInImage(["dpkg","--get-selections"],
+                         stdout=open(self.resultdir+"/fresh_install.pkgs","w"))
         self._runInImage(["tar","cvf","/tmp/etc-fresh.tar","/etc"])
         self._copyFromImage("/tmp/etc-fresh.tar", self.resultdir)
         self.stop()
@@ -191,7 +189,6 @@ class UpgradeTestBackendQemu(UpgradeTestBackendSSH):
         shutil.copy(self.baseimage, self.image)
 
         # get common vars
-        mirror = self.config.get("NonInteractive","Mirror")
         basepkg = self.config.get("NonInteractive","BasePkg")
         additional_base_pkgs = self.config.getlist("Distro","BaseMetaPkgs")
 
@@ -422,6 +419,15 @@ iface eth0 inet static
                     print "adding %s to mirrors" % entry.uri
                     self._runInImage(["echo '%s' >> /upgrade-tester/new_mirrors.cfg" % entry.uri])
                     
+            # upgrade *before* the regular upgrade runs 
+            if self.config.getWithDefault("NonInteractive", "AddRepoUpgradeImmediately", False):
+                self._runInImage(["apt-get", "update"])
+                self._runInImage(["DEBIAN_FRONTEND=noninteractive","apt-get","-y","dist-upgrade", "--allow-unauthenticated"])
+
+        apt_conf = self.config.getWithDefault("NonInteractive","AddAptConf","")
+        if apt_conf:
+            apt_conf = os.path.join(os.path.dirname(self.profile), apt_conf)
+            self._copyToImage(apt_conf, "/etc/apt/apt.conf.d")
 
         # check if we have a bzr checkout dir to run against or
         # if we should just run the normal upgrader
@@ -429,10 +435,15 @@ iface eth0 inet static
         if not self.config.getWithDefault("NonInteractive","ForceOverwrite", False):
             print "Disabling ForceOverwrite"
             cmd_prefix = ["export RELEASE_UPGRADE_NO_FORCE_OVERWRITE=1;"]
-        if os.path.exists(self.upgradefilesdir):
+        if (os.path.exists(self.upgradefilesdir) and
+            self.config.getWithDefault("NonInteractive", 
+                                       "UseUpgraderFromBzr", 
+                                       True)):
+            print "Using ./DistUpgrade/* for the upgrade"
             self._copyUpgraderFilesFromBzrCheckout()
             ret = self._runBzrCheckoutUpgrade(cmd_prefix)
         else:
+            print "Using do-release-upgrade for the upgrade"
             ret = self._runInImage(cmd_prefix+["do-release-upgrade","-d",
                                     "-f","DistUpgradeViewNonInteractive"])
         print "dist-upgrade.py returned: %i" % ret
@@ -451,7 +462,6 @@ iface eth0 inet static
         
 
 if __name__ == "__main__":
-    import sys
     
     # FIXME: very rough proof of conecpt, unify with the chroot
     #        and automatic-upgrade code
