@@ -4,12 +4,13 @@
 
 from aptdaemon import client, errors
 from defer import inline_callbacks
-from aptdaemon.gtkwidgets import AptProgressDialog
+from aptdaemon.gtk3widgets import AptProgressDialog
 from aptdaemon.enums import EXIT_SUCCESS
 
 from UpdateManager.backend import InstallBackend
+from UpdateManager.UnitySupport import UnitySupport
 
-import apt_pkg
+import apt
 import dbus
 
 class InstallBackendAptdaemon(InstallBackend):
@@ -19,12 +20,13 @@ class InstallBackendAptdaemon(InstallBackend):
     def __init__(self, window_main):
         InstallBackend.__init__(self, window_main)
         self.client = client.AptClient()
+        self.unity = UnitySupport()
 
     @inline_callbacks
     def update(self):
         """Refresh the package list"""
         try:
-            apt_pkg.pkgsystem_unlock()
+            apt.apt_pkg.pkgsystem_unlock()
         except SystemError:
             pass
         try:
@@ -40,7 +42,7 @@ class InstallBackendAptdaemon(InstallBackend):
     def commit(self, pkgs_install, pkgs_upgrade, close_on_done):
         """Commit a list of package adds and removes"""
         try:
-            apt_pkg.pkgsystem_unlock()
+            apt.apt_pkg.pkgsystem_unlock()
         except SystemError:
             pass
         try:
@@ -48,10 +50,12 @@ class InstallBackendAptdaemon(InstallBackend):
             trans = yield self.client.commit_packages(
                 pkgs_install, reinstall, remove, purge, pkgs_upgrade, 
                 downgrade, defer=True)
+            trans.connect("progress-changed", self._on_progress_changed)
             yield self._run_in_dialog(trans, self.INSTALL)
         except errors.NotAuthorizedError as e:
             self.emit("action-done", self.INSTALL, False, False)
         except dbus.DBusException as e:
+            #print e, e.get_dbus_name()
             if e.get_dbus_name() != "org.freedesktop.DBus.Error.NoReply":
                 raise
             self.emit("action-done", self.INSTALL, False, False)
@@ -59,6 +63,10 @@ class InstallBackendAptdaemon(InstallBackend):
             self.emit("action-done", self.INSTALL, True, False)
             raise
 
+    def _on_progress_changed(self, trans, progress):
+        #print "_on_progress_changed", progress
+        self.unity.set_progress(progress)
+
     @inline_callbacks
     def _run_in_dialog(self, trans, action):
         dia = AptProgressDialog(trans, parent=self.window_main)
@@ -68,14 +76,14 @@ class InstallBackendAptdaemon(InstallBackend):
 
     def _on_finished(self, dialog, action):
         dialog.hide()
+        # tell unity to hide the progress again
+        self.unity.set_progress(-1)
         self.emit("action-done", action, 
                   True, dialog._transaction.exit == EXIT_SUCCESS)
 
 if __name__ == "__main__":
-    import apt
-
     b = InstallBackendAptdaemon(None)
     b.commit(["2vcard"], [], False)
 
-    import gtk
-    gtk.main()
+    from gi.repository import Gtk
+    Gtk.main()
