@@ -6,7 +6,7 @@
 
 set -e
 
-DIST=natty
+DIST="$(lsb_release -c -s)"
 BASEDIR=./apt
 
 APT_OPTS="\
